UNIT Maus;    (* (c) ALFWARE B.Schubert *)

(*   y 
       |
       +---->x

       TextModus:     0..x..632   0..y..192   Delta: 8
       GraphikModus:  0..x..639   0..y..479   Delta: 1  *)

INTERFACE

USES DOS;

TYPE MAUSTYP = (mlinks,mrechts,mmittel);

PROCEDURE Maus_Driver(VAR io:BOOLEAN; VAR quali:INTEGER);
(* Ist der Maustreiber geladen ?
   Achtung: schaltet Maus aus ...  *)

PROCEDURE Maus_An;
(* schaltet Maus an *)

PROCEDURE Maus_Aus;
(* schaltet Maus aus *)

PROCEDURE Maus_Posit(VAR x,y:INTEGER; VAR links,mittel,rechts:BOOLEAN);
(* gibt die aktuelle Mausposition an, zustzlich ob eine Taste
   gerade(!) gedrckt ist                                            *)

PROCEDURE Maus_Setzen(x,y:INTEGER);
(* setzt die Maus auf Position x,y *)

PROCEDURE Maus_Taste(func:BOOLEAN;taste:MAUSTYP;
                     VAR indic:BOOLEAN; VAR anz,x,y:INTEGER);
(* Prft den Status der Maustasten
   func:  Bettigung    TRUE=gedrckt    FALSE=losgelassen
   taste: welche
   indic: Taste wird gerade(!) bettigt
   anz:   Taste wurde seit dem letzten Aufruf anz-mal bettigt
   x,y:   Taste wurde zuletzt bei x,y bettigt                      *)

PROCEDURE Maus_Feld(x1,y1,x2,y2:INTEGER);
(* Die Maus soll sich in den Koordinaten x1,y1 .. x2,y2 bewegen knnen *)

PROCEDURE Maus_Mode(code,farbe,grund:BYTE);
(* Die Maus (im Textmodus) bekommt die 'farbe' auf dem 'grund' wie
   angegeben und als Zeichen mit 'code'                             *)

PROCEDURE Maus_Richtung(VAR x,y:INTEGER);
(* Maus bewegt sich:
   x<0 .. nach links;   x>0 .. nach rechts
   y<0 .. nach unten;   y>0 .. nach oben   *)

FUNCTION Maus_Klick(mode:BYTE):BYTE;

IMPLEMENTATION

PROCEDURE INT33(VAR ax,bx,cx,dx:INTEGER);
VAR regs:REGISTERS;
BEGIN
  regs.AX:=ax; regs.BX:=bx; regs.CX:=cx; regs.DX:=dx; INTR($33,regs);
  ax:=regs.AX; bx:=regs.BX; cx:=regs.CX; dx:=regs.DX;
END;

PROCEDURE INT33a(ax,bx,cx,dx:INTEGER);
VAR regs:REGISTERS;
BEGIN
  regs.AX:=ax; regs.BX:=bx; regs.CX:=cx; regs.DX:=dx;
  INTR($33,regs);
END;

PROCEDURE Maus_Driver(VAR io:BOOLEAN; VAR quali:INTEGER);
VAR ax,bx,cx,dx:INTEGER;
BEGIN
  ax:=0; bx:=0; INT33(ax,bx,cx,dx);
  io:=(ax<>0); quali:=bx;
END;

PROCEDURE Maus_An; BEGIN INT33a(1,0,0,0) END;

PROCEDURE Maus_Aus; BEGIN INT33a(2,0,0,0) END;

PROCEDURE Maus_Posit(VAR x,y:INTEGER; VAR links,mittel,rechts:BOOLEAN);
VAR ax,bx,cx,dx:INTEGER;
BEGIN
  ax:=3; bx:=0; cx:=0; dx:=0; INT33(ax,bx,cx,dx);
  x:=cx; y:=dx;
  links:=(bx AND 1)<>0; rechts:=(bx AND 2)<>0; mittel:=(bx AND 4)<>0;
END;

PROCEDURE Maus_Setzen(x,y:INTEGER);
BEGIN
  INT33a(4,0,x,y);
END;

PROCEDURE Maus_Taste(func:BOOLEAN;taste:MAUSTYP;
                     VAR indic:BOOLEAN; VAR anz,x,y:INTEGER);
VAR ax,bx,cx,dx,temp:INTEGER;
BEGIN
  IF func THEN ax:=5 ELSE ax:=6;
  CASE taste OF mlinks: bx:=0; mrechts: bx:=1; mmittel: bx:=2; END;
  INT33(ax,bx,cx,dx);
  CASE taste OF mlinks: temp:=1; mrechts: temp:=2; mmittel: temp:=4; END;
  IF func THEN indic:=(ax AND temp)<>0 ELSE indic:=(ax AND temp)=0;
  anz:=bx; x:=cx; y:=dx;
END;

PROCEDURE Maus_Feld(x1,y1,x2,y2:INTEGER);
BEGIN
  INT33a(7,0,x1,x2); INT33a(8,0,y1,y2)
END;

PROCEDURE Maus_Mode(code,farbe,grund:BYTE);
BEGIN
  INT33a(10,0,0,code+(grund MOD 16) SHL 12+(farbe MOD 16) SHL 8);
END;

PROCEDURE Maus_Richtung(VAR x,y:INTEGER);
VAR ax,bx,cx,dx:INTEGER;
BEGIN
  ax:=11; bx:=0; cx:=0; dx:=0; INT33(ax,bx,cx,dx); x:=cx; y:=-dx;
END;

FUNCTION Maus_Klick(mode:BYTE):BYTE;
VAR indic:BOOLEAN; anz,x,y:INTEGER; count:LONGINT;
BEGIN
  Maus_Taste(TRUE,mlinks,indic,anz,x,y);
  IF mode<>0
    THEN Maus_klick:=anz
    ELSE BEGIN
      Maus_Klick:=0;
      count:=0; REPEAT INC(count); UNTIL count>1000000;
  END;
END;

BEGIN
END (* Maus.TPU *).